"""This module contains the general information for ConfigImpact ManagedObject."""

from ...ucsmo import ManagedObject
from ...ucscoremeta import MoPropertyMeta, MoMeta
from ...ucsmeta import VersionMeta


class ConfigImpactConsts:
    CHASSIS_CONFIG_STATE_APPLIED = "applied"
    CHASSIS_CONFIG_STATE_APPLYING = "applying"
    CHASSIS_CONFIG_STATE_FAILED_TO_APPLY = "failed-to-apply"
    CHASSIS_CONFIG_STATE_NOT_APPLIED = "not-applied"
    CONFIG_STATE_APPLIED = "applied"
    CONFIG_STATE_APPLYING = "applying"
    CONFIG_STATE_FAILED_TO_APPLY = "failed-to-apply"
    CONFIG_STATE_NOT_APPLIED = "not-applied"
    DEPLOYMENT_MODE_IMMEDIATE = "immediate"
    DEPLOYMENT_MODE_TIMER_AUTOMATIC = "timer-automatic"
    DEPLOYMENT_MODE_USER_ACK = "user-ack"
    REBOOT_REQUIRED_FALSE = "false"
    REBOOT_REQUIRED_NO = "no"
    REBOOT_REQUIRED_TRUE = "true"
    REBOOT_REQUIRED_YES = "yes"


class ConfigImpact(ManagedObject):
    """This is ConfigImpact class."""

    consts = ConfigImpactConsts()
    naming_props = set(['name'])

    mo_meta = MoMeta("ConfigImpact", "configImpact", "impact-[name]", VersionMeta.Version212a, "InputOutput", 0x3f, [], ["read-only"], ['configManagedEpImpactResponse'], [], [None])

    prop_meta = {
        "affected_chassis": MoPropertyMeta("affected_chassis", "affectedChassis", "string", VersionMeta.Version312b, MoPropertyMeta.READ_ONLY, None, 0, 256, None, [], []),
        "affected_obj": MoPropertyMeta("affected_obj", "affectedObj", "string", VersionMeta.Version212a, MoPropertyMeta.READ_ONLY, None, 0, 256, None, [], []),
        "affected_server": MoPropertyMeta("affected_server", "affectedServer", "string", VersionMeta.Version212a, MoPropertyMeta.READ_ONLY, None, 0, 256, None, [], []),
        "changes": MoPropertyMeta("changes", "changes", "string", VersionMeta.Version212a, MoPropertyMeta.READ_ONLY, None, None, None, r"""((defaultValue|boot-order|server-assignment|operational-policies|local-storage|server-identity|storage|networking|vnic-vhba-placement),){0,8}(defaultValue|boot-order|server-assignment|operational-policies|local-storage|server-identity|storage|networking|vnic-vhba-placement){0,1}""", [], []),
        "chassis_config_issues": MoPropertyMeta("chassis_config_issues", "chassisConfigIssues", "string", VersionMeta.Version312b, MoPropertyMeta.READ_ONLY, None, None, None, r"""((defaultValue|not-applicable|chassis-profile-not-supported|single-path-not-supported|invalid-cmc-version|migration|single-path-unsupported-cmc-version|single-path-operation-not-supported|firmware-version-mismatch|invalid-sas-exp-config-policy-reference|non-interrupt-fsm-running|insufficient-resources|compute-conn-invalid-hw-config|connection-management-unsupported-cmc-version|physical-requirement|single-path-expander-inoperable|connection-management-feature-not-supported|chassis-undiscovered|chassis-feature-capability-mismatch|resource-ownership-conflict|unsupported-sas-exp-config-settings|compute-conn-unsupported-cmc-version|connection-management-expander-inoperable|chassis-unavailable|invalid-chassis-pack|single-path-invalid-configuration|connection-management-operation-not-supported|missing-firmware-image|chassis-feature-capability-mismatch-non-fatal|single-path-feature-not-supported|compute-second-controller-unsupported-cmc-version|connection-management-not-supported|insufficient-power-budget),){0,32}(defaultValue|not-applicable|chassis-profile-not-supported|single-path-not-supported|invalid-cmc-version|migration|single-path-unsupported-cmc-version|single-path-operation-not-supported|firmware-version-mismatch|invalid-sas-exp-config-policy-reference|non-interrupt-fsm-running|insufficient-resources|compute-conn-invalid-hw-config|connection-management-unsupported-cmc-version|physical-requirement|single-path-expander-inoperable|connection-management-feature-not-supported|chassis-undiscovered|chassis-feature-capability-mismatch|resource-ownership-conflict|unsupported-sas-exp-config-settings|compute-conn-unsupported-cmc-version|connection-management-expander-inoperable|chassis-unavailable|invalid-chassis-pack|single-path-invalid-configuration|connection-management-operation-not-supported|missing-firmware-image|chassis-feature-capability-mismatch-non-fatal|single-path-feature-not-supported|compute-second-controller-unsupported-cmc-version|connection-management-not-supported|insufficient-power-budget){0,1}""", [], []),
        "chassis_config_qualifier": MoPropertyMeta("chassis_config_qualifier", "chassisConfigQualifier", "string", VersionMeta.Version312b, MoPropertyMeta.READ_ONLY, None, None, None, r"""((defaultValue|not-applicable|chassis-profile-not-supported|single-path-not-supported|invalid-cmc-version|migration|single-path-unsupported-cmc-version|single-path-operation-not-supported|firmware-version-mismatch|invalid-sas-exp-config-policy-reference|non-interrupt-fsm-running|insufficient-resources|compute-conn-invalid-hw-config|connection-management-unsupported-cmc-version|physical-requirement|single-path-expander-inoperable|connection-management-feature-not-supported|chassis-undiscovered|chassis-feature-capability-mismatch|resource-ownership-conflict|unsupported-sas-exp-config-settings|compute-conn-unsupported-cmc-version|connection-management-expander-inoperable|chassis-unavailable|invalid-chassis-pack|single-path-invalid-configuration|connection-management-operation-not-supported|missing-firmware-image|chassis-feature-capability-mismatch-non-fatal|single-path-feature-not-supported|compute-second-controller-unsupported-cmc-version|connection-management-not-supported|insufficient-power-budget),){0,32}(defaultValue|not-applicable|chassis-profile-not-supported|single-path-not-supported|invalid-cmc-version|migration|single-path-unsupported-cmc-version|single-path-operation-not-supported|firmware-version-mismatch|invalid-sas-exp-config-policy-reference|non-interrupt-fsm-running|insufficient-resources|compute-conn-invalid-hw-config|connection-management-unsupported-cmc-version|physical-requirement|single-path-expander-inoperable|connection-management-feature-not-supported|chassis-undiscovered|chassis-feature-capability-mismatch|resource-ownership-conflict|unsupported-sas-exp-config-settings|compute-conn-unsupported-cmc-version|connection-management-expander-inoperable|chassis-unavailable|invalid-chassis-pack|single-path-invalid-configuration|connection-management-operation-not-supported|missing-firmware-image|chassis-feature-capability-mismatch-non-fatal|single-path-feature-not-supported|compute-second-controller-unsupported-cmc-version|connection-management-not-supported|insufficient-power-budget){0,1}""", [], []),
        "chassis_config_state": MoPropertyMeta("chassis_config_state", "chassisConfigState", "string", VersionMeta.Version312b, MoPropertyMeta.READ_ONLY, None, None, None, None, ["applied", "applying", "failed-to-apply", "not-applied"], []),
        "child_action": MoPropertyMeta("child_action", "childAction", "string", VersionMeta.Version212a, MoPropertyMeta.INTERNAL, 0x2, None, None, r"""((deleteAll|ignore|deleteNonPresent),){0,2}(deleteAll|ignore|deleteNonPresent){0,1}""", [], []),
        "config_issues": MoPropertyMeta("config_issues", "configIssues", "string", VersionMeta.Version212a, MoPropertyMeta.READ_ONLY, None, None, None, r"""((defaultValue|not-applicable|boot-order-pxe|wwnn-derivation-from-vhba|migration|incompat-bios-for-sriov-vnics|iscsi-initiator-ip-address|remote-policy|wwnn-assignment|processor-requirement|physical-requirement|hostimg-policy-invalid|vif-resources-overprovisioned|pinning-invalid|incompatible-number-of-local-disks|mac-derivation-virtualized-port|switch-virtual-if-capacity|invalid-wwn|missing-raid-key|board-controller-update-unsupported|insufficient-resources|compute-undiscovered|boot-configuration-invalid|incompatible-bios-image|iscsi-config|storage-path-configuration-error|resource-ownership-conflict|system-uuid-assignment|server-position-requirement|destructive-local-disk-config|imgsec-policy-invalid|pinning-vlan-mismatch|non-interrupt-fsm-running|vnic-capacity|adaptor-requirement|mac-address-assignment|qos-policy-invalid|insufficient-power-budget|boot-order-iscsi|vnic-vcon-provisioning-change|adaptor-protected-eth-capability|connection-placement|incompatible-disk-types|vnic-not-ha-ready|zone-capacity|adaptor-out-of-vifs|duplicate-address-conflict|vhba-capacity|boot-order-san-image-path|compute-unavailable|power-group-requirement|provsrv-policy-invalid|vnic-vlan-assignment-error|missing-firmware-image|wwpn-assignment|memory-requirement|vlan-port-capacity|bootip-policy-invalid|vfc-vnic-pvlan-conflict|named-vlan-inaccessible|adaptor-fcoe-capability|wwpn-derivation-virtualized-port|incompatible-raid-level|missing-primary-vlan|fcoe-capacity|dynamic-vf-vnic),){0,65}(defaultValue|not-applicable|boot-order-pxe|wwnn-derivation-from-vhba|migration|incompat-bios-for-sriov-vnics|iscsi-initiator-ip-address|remote-policy|wwnn-assignment|processor-requirement|physical-requirement|hostimg-policy-invalid|vif-resources-overprovisioned|pinning-invalid|incompatible-number-of-local-disks|mac-derivation-virtualized-port|switch-virtual-if-capacity|invalid-wwn|missing-raid-key|board-controller-update-unsupported|insufficient-resources|compute-undiscovered|boot-configuration-invalid|incompatible-bios-image|iscsi-config|storage-path-configuration-error|resource-ownership-conflict|system-uuid-assignment|server-position-requirement|destructive-local-disk-config|imgsec-policy-invalid|pinning-vlan-mismatch|non-interrupt-fsm-running|vnic-capacity|adaptor-requirement|mac-address-assignment|qos-policy-invalid|insufficient-power-budget|boot-order-iscsi|vnic-vcon-provisioning-change|adaptor-protected-eth-capability|connection-placement|incompatible-disk-types|vnic-not-ha-ready|zone-capacity|adaptor-out-of-vifs|duplicate-address-conflict|vhba-capacity|boot-order-san-image-path|compute-unavailable|power-group-requirement|provsrv-policy-invalid|vnic-vlan-assignment-error|missing-firmware-image|wwpn-assignment|memory-requirement|vlan-port-capacity|bootip-policy-invalid|vfc-vnic-pvlan-conflict|named-vlan-inaccessible|adaptor-fcoe-capability|wwpn-derivation-virtualized-port|incompatible-raid-level|missing-primary-vlan|fcoe-capacity|dynamic-vf-vnic){0,1}""", [], []),
        "config_qualifier": MoPropertyMeta("config_qualifier", "configQualifier", "string", VersionMeta.Version212a, MoPropertyMeta.READ_ONLY, None, None, None, r"""((defaultValue|not-applicable|boot-order-pxe|wwnn-derivation-from-vhba|migration|incompat-bios-for-sriov-vnics|iscsi-initiator-ip-address|remote-policy|wwnn-assignment|processor-requirement|physical-requirement|hostimg-policy-invalid|vif-resources-overprovisioned|pinning-invalid|incompatible-number-of-local-disks|mac-derivation-virtualized-port|switch-virtual-if-capacity|invalid-wwn|missing-raid-key|board-controller-update-unsupported|insufficient-resources|compute-undiscovered|boot-configuration-invalid|incompatible-bios-image|iscsi-config|storage-path-configuration-error|resource-ownership-conflict|system-uuid-assignment|server-position-requirement|destructive-local-disk-config|imgsec-policy-invalid|pinning-vlan-mismatch|non-interrupt-fsm-running|vnic-capacity|adaptor-requirement|mac-address-assignment|qos-policy-invalid|insufficient-power-budget|boot-order-iscsi|vnic-vcon-provisioning-change|adaptor-protected-eth-capability|connection-placement|incompatible-disk-types|vnic-not-ha-ready|zone-capacity|adaptor-out-of-vifs|duplicate-address-conflict|vhba-capacity|boot-order-san-image-path|compute-unavailable|power-group-requirement|provsrv-policy-invalid|vnic-vlan-assignment-error|missing-firmware-image|wwpn-assignment|memory-requirement|vlan-port-capacity|bootip-policy-invalid|vfc-vnic-pvlan-conflict|named-vlan-inaccessible|adaptor-fcoe-capability|wwpn-derivation-virtualized-port|incompatible-raid-level|missing-primary-vlan|fcoe-capacity|dynamic-vf-vnic),){0,65}(defaultValue|not-applicable|boot-order-pxe|wwnn-derivation-from-vhba|migration|incompat-bios-for-sriov-vnics|iscsi-initiator-ip-address|remote-policy|wwnn-assignment|processor-requirement|physical-requirement|hostimg-policy-invalid|vif-resources-overprovisioned|pinning-invalid|incompatible-number-of-local-disks|mac-derivation-virtualized-port|switch-virtual-if-capacity|invalid-wwn|missing-raid-key|board-controller-update-unsupported|insufficient-resources|compute-undiscovered|boot-configuration-invalid|incompatible-bios-image|iscsi-config|storage-path-configuration-error|resource-ownership-conflict|system-uuid-assignment|server-position-requirement|destructive-local-disk-config|imgsec-policy-invalid|pinning-vlan-mismatch|non-interrupt-fsm-running|vnic-capacity|adaptor-requirement|mac-address-assignment|qos-policy-invalid|insufficient-power-budget|boot-order-iscsi|vnic-vcon-provisioning-change|adaptor-protected-eth-capability|connection-placement|incompatible-disk-types|vnic-not-ha-ready|zone-capacity|adaptor-out-of-vifs|duplicate-address-conflict|vhba-capacity|boot-order-san-image-path|compute-unavailable|power-group-requirement|provsrv-policy-invalid|vnic-vlan-assignment-error|missing-firmware-image|wwpn-assignment|memory-requirement|vlan-port-capacity|bootip-policy-invalid|vfc-vnic-pvlan-conflict|named-vlan-inaccessible|adaptor-fcoe-capability|wwpn-derivation-virtualized-port|incompatible-raid-level|missing-primary-vlan|fcoe-capacity|dynamic-vf-vnic){0,1}""", [], []),
        "config_state": MoPropertyMeta("config_state", "configState", "string", VersionMeta.Version212a, MoPropertyMeta.READ_ONLY, None, None, None, None, ["applied", "applying", "failed-to-apply", "not-applied"], []),
        "deployment_mode": MoPropertyMeta("deployment_mode", "deploymentMode", "string", VersionMeta.Version212a, MoPropertyMeta.READ_ONLY, None, None, None, None, ["immediate", "timer-automatic", "user-ack"], []),
        "dn": MoPropertyMeta("dn", "dn", "string", VersionMeta.Version212a, MoPropertyMeta.READ_ONLY, 0x4, 0, 256, None, [], []),
        "name": MoPropertyMeta("name", "name", "string", VersionMeta.Version212a, MoPropertyMeta.NAMING, 0x8, 1, 510, None, [], []),
        "reboot_required": MoPropertyMeta("reboot_required", "rebootRequired", "string", VersionMeta.Version212a, MoPropertyMeta.READ_ONLY, None, None, None, None, ["false", "no", "true", "yes"], []),
        "rn": MoPropertyMeta("rn", "rn", "string", VersionMeta.Version212a, MoPropertyMeta.READ_ONLY, 0x10, 0, 256, None, [], []),
        "sacl": MoPropertyMeta("sacl", "sacl", "string", VersionMeta.Version302c, MoPropertyMeta.READ_ONLY, None, None, None, r"""((none|del|mod|addchild|cascade),){0,4}(none|del|mod|addchild|cascade){0,1}""", [], []),
        "status": MoPropertyMeta("status", "status", "string", VersionMeta.Version212a, MoPropertyMeta.READ_WRITE, 0x20, None, None, r"""((removed|created|modified|deleted),){0,3}(removed|created|modified|deleted){0,1}""", [], []),
    }

    prop_map = {
        "affectedChassis": "affected_chassis", 
        "affectedObj": "affected_obj", 
        "affectedServer": "affected_server", 
        "changes": "changes", 
        "chassisConfigIssues": "chassis_config_issues", 
        "chassisConfigQualifier": "chassis_config_qualifier", 
        "chassisConfigState": "chassis_config_state", 
        "childAction": "child_action", 
        "configIssues": "config_issues", 
        "configQualifier": "config_qualifier", 
        "configState": "config_state", 
        "deploymentMode": "deployment_mode", 
        "dn": "dn", 
        "name": "name", 
        "rebootRequired": "reboot_required", 
        "rn": "rn", 
        "sacl": "sacl", 
        "status": "status", 
    }

    def __init__(self, parent_mo_or_dn, name, **kwargs):
        self._dirty_mask = 0
        self.name = name
        self.affected_chassis = None
        self.affected_obj = None
        self.affected_server = None
        self.changes = None
        self.chassis_config_issues = None
        self.chassis_config_qualifier = None
        self.chassis_config_state = None
        self.child_action = None
        self.config_issues = None
        self.config_qualifier = None
        self.config_state = None
        self.deployment_mode = None
        self.reboot_required = None
        self.sacl = None
        self.status = None

        ManagedObject.__init__(self, "ConfigImpact", parent_mo_or_dn, **kwargs)



"""This module contains the meta information of ConfigConfRename ExternalMethod."""

from ..ucscoremeta import MethodMeta, MethodPropertyMeta

method_meta = MethodMeta("ConfigConfRename", "configConfRename", "Version142b")

prop_meta = {
    "cookie": MethodPropertyMeta("Cookie", "cookie", "Xs:string", "Version142b", "InputOutput", False),
    "dn": MethodPropertyMeta("Dn", "dn", "ReferenceObject", "Version142b", "InputOutput", False),
    "in_hierarchical": MethodPropertyMeta("InHierarchical", "inHierarchical", "Xs:string", "Version142b", "Input", False),
    "in_new_name": MethodPropertyMeta("InNewName", "inNewName", "Xs:string", "Version142b", "Input", False),
    "out_config": MethodPropertyMeta("OutConfig", "outConfig", "ConfigConfig", "Version142b", "Output", True),
}

prop_map = {
    "cookie": "cookie",
    "dn": "dn",
    "inHierarchical": "in_hierarchical",
    "inNewName": "in_new_name",
    "outConfig": "out_config",
}



"""This module contains the general information for EquipmentInventoryStatus ManagedObject."""

from ...ucsmo import ManagedObject
from ...ucscoremeta import MoPropertyMeta, MoMeta
from ...ucsmeta import VersionMeta


class EquipmentInventoryStatusConsts:
    CLEANUP_PARENT_ON_DISCOVERY_FALSE = "false"
    CLEANUP_PARENT_ON_DISCOVERY_NO = "no"
    CLEANUP_PARENT_ON_DISCOVERY_TRUE = "true"
    CLEANUP_PARENT_ON_DISCOVERY_YES = "yes"


class EquipmentInventoryStatus(ManagedObject):
    """This is EquipmentInventoryStatus class."""

    consts = EquipmentInventoryStatusConsts()
    naming_props = set([])

    mo_meta = MoMeta("EquipmentInventoryStatus", "equipmentInventoryStatus", "inv-status", VersionMeta.Version321d, "InputOutput", 0x3f, [], ["read-only"], ['adaptorUnit', 'adaptorUnitExtn', 'computeBlade', 'computeRackUnit', 'computeServerUnit', 'graphicsCard', 'memoryUnit', 'processorUnit', 'securityUnit', 'storageController', 'storageMiniStorage'], ['faultInst'], ["Get", "Set"])

    prop_meta = {
        "child_action": MoPropertyMeta("child_action", "childAction", "string", VersionMeta.Version321d, MoPropertyMeta.INTERNAL, 0x2, None, None, r"""((deleteAll|ignore|deleteNonPresent),){0,2}(deleteAll|ignore|deleteNonPresent){0,1}""", [], []),
        "cleanup_parent_on_discovery": MoPropertyMeta("cleanup_parent_on_discovery", "cleanupParentOnDiscovery", "string", VersionMeta.Version321d, MoPropertyMeta.READ_ONLY, None, None, None, None, ["false", "no", "true", "yes"], []),
        "dn": MoPropertyMeta("dn", "dn", "string", VersionMeta.Version321d, MoPropertyMeta.READ_ONLY, 0x4, 0, 256, None, [], []),
        "hw_inventory_status": MoPropertyMeta("hw_inventory_status", "hwInventoryStatus", "string", VersionMeta.Version321d, MoPropertyMeta.READ_ONLY, None, None, None, r"""((defaultValue|ok|pci-config-mismatch|mismatch|insertion|persistent-memory-detection|removal|replacement),){0,7}(defaultValue|ok|pci-config-mismatch|mismatch|insertion|persistent-memory-detection|removal|replacement){0,1}""", [], []),
        "id": MoPropertyMeta("id", "id", "uint", VersionMeta.Version321d, MoPropertyMeta.READ_WRITE, 0x8, None, None, None, [], []),
        "model": MoPropertyMeta("model", "model", "string", VersionMeta.Version321d, MoPropertyMeta.READ_ONLY, None, 0, 510, None, [], []),
        "revision": MoPropertyMeta("revision", "revision", "string", VersionMeta.Version321d, MoPropertyMeta.READ_ONLY, None, 0, 510, None, [], []),
        "rn": MoPropertyMeta("rn", "rn", "string", VersionMeta.Version321d, MoPropertyMeta.READ_ONLY, 0x10, 0, 256, None, [], []),
        "sacl": MoPropertyMeta("sacl", "sacl", "string", VersionMeta.Version321d, MoPropertyMeta.READ_ONLY, None, None, None, r"""((none|del|mod|addchild|cascade),){0,4}(none|del|mod|addchild|cascade){0,1}""", [], []),
        "serial": MoPropertyMeta("serial", "serial", "string", VersionMeta.Version321d, MoPropertyMeta.READ_ONLY, None, 0, 510, None, [], []),
        "status": MoPropertyMeta("status", "status", "string", VersionMeta.Version321d, MoPropertyMeta.READ_WRITE, 0x20, None, None, r"""((removed|created|modified|deleted),){0,3}(removed|created|modified|deleted){0,1}""", [], []),
        "vendor": MoPropertyMeta("vendor", "vendor", "string", VersionMeta.Version321d, MoPropertyMeta.READ_ONLY, None, 0, 510, None, [], []),
    }

    prop_map = {
        "childAction": "child_action", 
        "cleanupParentOnDiscovery": "cleanup_parent_on_discovery", 
        "dn": "dn", 
        "hwInventoryStatus": "hw_inventory_status", 
        "id": "id", 
        "model": "model", 
        "revision": "revision", 
        "rn": "rn", 
        "sacl": "sacl", 
        "serial": "serial", 
        "status": "status", 
        "vendor": "vendor", 
    }

    def __init__(self, parent_mo_or_dn, **kwargs):
        self._dirty_mask = 0
        self.child_action = None
        self.cleanup_parent_on_discovery = None
        self.hw_inventory_status = None
        self.id = None
        self.model = None
        self.revision = None
        self.sacl = None
        self.serial = None
        self.status = None
        self.vendor = None

        ManagedObject.__init__(self, "EquipmentInventoryStatus", parent_mo_or_dn, **kwargs)



"""This module contains the general information for TopSystem ManagedObject."""

from ...ucsmo import ManagedObject
from ...ucscoremeta import MoPropertyMeta, MoMeta
from ...ucsmeta import VersionMeta


class TopSystemConsts:
    MODE_CLUSTER = "cluster"
    MODE_STAND_ALONE = "stand-alone"
    MODE_UNSPECIFIED = "unspecified"


class TopSystem(ManagedObject):
    """This is TopSystem class."""

    consts = TopSystemConsts()
    naming_props = set([])

    mo_meta = MoMeta("TopSystem", "topSystem", "sys", VersionMeta.Version101e, "InputOutput", 0x7ff, [], ["admin", "ext-lan-config"], ['topRoot'], ['aaaAuthRealm', 'aaaLdapEp', 'aaaRadiusEp', 'aaaSessionInfoTable', 'aaaTacacsPlusEp', 'aaaUserEp', 'cloudMgmtSvc', 'commSvcEp', 'computeRackUnit', 'controllerHaController', 'controllerMgmtDbCheckPol', 'domainChassisFeatureCont', 'domainEnvironmentFeatureCont', 'domainNetworkFeatureCont', 'domainServerFeatureCont', 'domainStorageFeatureCont', 'equipmentChassis', 'equipmentFex', 'equipmentRackEnclosure', 'extmgmtIfMonPolicy', 'extvmmEp', 'featureContextEp', 'firmwareCatalogue', 'firmwareStatus', 'firmwareSystem', 'firmwareUpgradeInfo', 'fsmStatus', 'initiatorRequestorEp', 'initiatorRequestorGrpEp', 'licenseEp', 'mgmtAccessPolicy', 'mgmtBackup', 'mgmtBackupPolicyConfig', 'mgmtController', 'mgmtEntity', 'mgmtImporter', 'mgmtIntAuthPolicy', 'networkElement', 'pkiEp', 'policyControlEp', 'powerEp', 'swatInjection', 'syntheticDirectory', 'syntheticFsObj', 'sysdebugCoreFileRepository', 'sysdebugDiagnosticLogRepository', 'sysdebugEp', 'sysdebugTechSupFileRepository', 'topInfoPolicy', 'trigLocalSched', 'trigMeta', 'trigSched', 'versionEp'], ["Get", "Set"])

    prop_meta = {
        "address": MoPropertyMeta("address", "address", "string", VersionMeta.Version101e, MoPropertyMeta.READ_WRITE, 0x2, 0, 256, r"""((([0-9]){1,3}\.){3}[0-9]{1,3})""", [], []),
        "child_action": MoPropertyMeta("child_action", "childAction", "string", VersionMeta.Version101e, MoPropertyMeta.INTERNAL, 0x4, None, None, r"""((deleteAll|ignore|deleteNonPresent),){0,2}(deleteAll|ignore|deleteNonPresent){0,1}""", [], []),
        "current_time": MoPropertyMeta("current_time", "currentTime", "string", VersionMeta.Version101e, MoPropertyMeta.READ_ONLY, None, None, None, r"""([0-9]){4}-([0-9]){2}-([0-9]){2}T([0-9]){2}:([0-9]){2}:([0-9]){2}((\.([0-9]){3})){0,1}""", [], []),
        "descr": MoPropertyMeta("descr", "descr", "string", VersionMeta.Version211a, MoPropertyMeta.READ_WRITE, 0x8, None, None, r"""[ !#$%&\(\)\*\+,\-\./:;\?@\[\]_\{\|\}~a-zA-Z0-9]{0,256}""", [], []),
        "dn": MoPropertyMeta("dn", "dn", "string", VersionMeta.Version101e, MoPropertyMeta.READ_ONLY, 0x10, 0, 256, None, [], []),
        "ipv6_addr": MoPropertyMeta("ipv6_addr", "ipv6Addr", "string", VersionMeta.Version221b, MoPropertyMeta.READ_WRITE, 0x20, 0, 256, None, [], []),
        "mode": MoPropertyMeta("mode", "mode", "string", VersionMeta.Version101e, MoPropertyMeta.READ_ONLY, None, None, None, None, ["cluster", "stand-alone", "unspecified"], []),
        "name": MoPropertyMeta("name", "name", "string", VersionMeta.Version101e, MoPropertyMeta.READ_WRITE, 0x40, None, None, r"""[a-zA-Z][a-zA-Z0-9-]{0,29}""", [], []),
        "owner": MoPropertyMeta("owner", "owner", "string", VersionMeta.Version211a, MoPropertyMeta.READ_WRITE, 0x80, None, None, r"""[ !#$%&\(\)\*\+,\-\./:;\?@\[\]_\{\|\}~a-zA-Z0-9]{0,32}""", [], []),
        "rn": MoPropertyMeta("rn", "rn", "string", VersionMeta.Version101e, MoPropertyMeta.READ_ONLY, 0x100, 0, 256, None, [], []),
        "sacl": MoPropertyMeta("sacl", "sacl", "string", VersionMeta.Version302c, MoPropertyMeta.READ_ONLY, None, None, None, r"""((none|del|mod|addchild|cascade),){0,4}(none|del|mod|addchild|cascade){0,1}""", [], []),
        "site": MoPropertyMeta("site", "site", "string", VersionMeta.Version211a, MoPropertyMeta.READ_WRITE, 0x200, None, None, r"""[ !#$%&\(\)\*\+,\-\./:;\?@\[\]_\{\|\}~a-zA-Z0-9]{0,32}""", [], []),
        "status": MoPropertyMeta("status", "status", "string", VersionMeta.Version101e, MoPropertyMeta.READ_WRITE, 0x400, None, None, r"""((removed|created|modified|deleted),){0,3}(removed|created|modified|deleted){0,1}""", [], []),
        "system_up_time": MoPropertyMeta("system_up_time", "systemUpTime", "string", VersionMeta.Version101e, MoPropertyMeta.READ_ONLY, None, None, None, r"""(([1-9]*[0-9]{2}:)|)([0-1][0-9]||[2][0-3]):([0-5][0-9]):([0-5][0-9])||(([0-5][0-9]):|)([0-5][0-9])""", [], []),
    }

    prop_map = {
        "address": "address", 
        "childAction": "child_action", 
        "currentTime": "current_time", 
        "descr": "descr", 
        "dn": "dn", 
        "ipv6Addr": "ipv6_addr", 
        "mode": "mode", 
        "name": "name", 
        "owner": "owner", 
        "rn": "rn", 
        "sacl": "sacl", 
        "site": "site", 
        "status": "status", 
        "systemUpTime": "system_up_time", 
    }

    def __init__(self, **kwargs):
        self._dirty_mask = 0
        self.address = None
        self.child_action = None
        self.current_time = None
        self.descr = None
        self.ipv6_addr = None
        self.mode = None
        self.name = None
        self.owner = None
        self.sacl = None
        self.site = None
        self.status = None
        self.system_up_time = None

        ManagedObject.__init__(self, "TopSystem", **kwargs)



"""This module contains the general information for EquipmentSlotArray ManagedObject."""

from ...ucsmo import ManagedObject
from ...ucscoremeta import MoPropertyMeta, MoMeta
from ...ucsmeta import VersionMeta


class EquipmentSlotArrayConsts:
    DEVICE_SLOT_OFFSET_UNDEFINED = "undefined"
    HEIGHT_NOT_APPLICABLE = "not-applicable"
    HORIZONTAL_START_OFFSET_NOT_APPLICABLE = "not-applicable"
    INLINE_GROUP_SEPARATION_NOT_APPLICABLE = "not-applicable"
    INLINE_OFFSET_NOT_APPLICABLE = "not-applicable"
    INT_ID_NONE = "none"
    LOCATION_BACK = "back"
    LOCATION_BOTTOM = "bottom"
    LOCATION_FRONT = "front"
    LOCATION_LEFT = "left"
    LOCATION_RIGHT = "right"
    LOCATION_TOP = "top"
    LOCATION_UNKNOWN = "unknown"
    ORIENTATION_HORIZONTAL = "horizontal"
    ORIENTATION_UNKNOWN = "unknown"
    ORIENTATION_VERTICAL = "vertical"
    POLICY_OWNER_LOCAL = "local"
    POLICY_OWNER_PENDING_POLICY = "pending-policy"
    POLICY_OWNER_POLICY = "policy"
    SELECTOR_BLADE = "blade"
    SELECTOR_COM_PORT = "com_port"
    SELECTOR_DISK_SLOT = "disk_slot"
    SELECTOR_DRIVE_SLOT = "drive_slot"
    SELECTOR_DVI_PORT = "dvi_port"
    SELECTOR_ETHERNET_PORT = "ethernet_port"
    SELECTOR_FAN = "fan"
    SELECTOR_GEM = "gem"
    SELECTOR_IOCARD = "iocard"
    SELECTOR_KEYBOARD_PORT = "keyboard_port"
    SELECTOR_MOUSE_PORT = "mouse_port"
    SELECTOR_PAR_PORT = "par_port"
    SELECTOR_PSU = "psu"
    SELECTOR_UNKNOWN = "unknown"
    SELECTOR_USB_PORT = "usb_port"
    SELECTOR_VGA_PORT = "vga_port"
    SUB_OEM_ID_UNDEFINED = "undefined"
    TRANSVERSE_GROUP_SEPARATION_NOT_APPLICABLE = "not-applicable"
    TRANSVERSE_OFFSET_NOT_APPLICABLE = "not-applicable"
    VERTICAL_START_OFFSET_NOT_APPLICABLE = "not-applicable"
    WIDTH_NOT_APPLICABLE = "not-applicable"


class EquipmentSlotArray(ManagedObject):
    """This is EquipmentSlotArray class."""

    consts = EquipmentSlotArrayConsts()
    naming_props = set(['selector'])

    mo_meta = MoMeta("EquipmentSlotArray", "equipmentSlotArray", "[selector]", VersionMeta.Version101e, "InputOutput", 0x1ff, [], [""], ['diagSrvCapProvider', 'equipmentBladeCapProvider', 'equipmentCatalogCapProvider', 'equipmentChassisCapProvider', 'equipmentDbgPluginCapProvider', 'equipmentIOExpanderCapProvider', 'equipmentMgmtCapProvider', 'equipmentMgmtExtCapProvider', 'equipmentRackEnclosureCapProvider', 'equipmentRackUnitCapProvider', 'equipmentServerUnitCapProvider', 'equipmentSiocCapProvider', 'equipmentStorageEncCapProvider', 'equipmentSwitchCapProvider'], [], ["Get"])

    prop_meta = {
        "child_action": MoPropertyMeta("child_action", "childAction", "string", VersionMeta.Version101e, MoPropertyMeta.INTERNAL, 0x2, None, None, r"""((deleteAll|ignore|deleteNonPresent),){0,2}(deleteAll|ignore|deleteNonPresent){0,1}""", [], []),
        "descr": MoPropertyMeta("descr", "descr", "string", VersionMeta.Version101e, MoPropertyMeta.READ_WRITE, 0x4, None, None, r"""[ !#$%&\(\)\*\+,\-\./:;\?@\[\]_\{\|\}~a-zA-Z0-9]{0,256}""", [], []),
        "device_slot_offset": MoPropertyMeta("device_slot_offset", "deviceSlotOffset", "string", VersionMeta.Version224b, MoPropertyMeta.READ_ONLY, None, None, None, None, ["undefined"], ["0-65535"]),
        "dn": MoPropertyMeta("dn", "dn", "string", VersionMeta.Version101e, MoPropertyMeta.READ_ONLY, 0x8, 0, 256, None, [], []),
        "first_index": MoPropertyMeta("first_index", "firstIndex", "ushort", VersionMeta.Version101e, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []),
        "height": MoPropertyMeta("height", "height", "string", VersionMeta.Version101e, MoPropertyMeta.READ_ONLY, None, None, None, r"""^([\-]?)([123]?[1234]?)([0-9]{0,36})(([.])([0-9]{1,10}))?$""", ["not-applicable"], ["0-4294967295"]),
        "horizontal_start_offset": MoPropertyMeta("horizontal_start_offset", "horizontalStartOffset", "string", VersionMeta.Version101e, MoPropertyMeta.READ_ONLY, None, None, None, r"""^([\-]?)([123]?[1234]?)([0-9]{0,36})(([.])([0-9]{1,10}))?$""", ["not-applicable"], ["0-4294967295"]),
        "inline_group_separation": MoPropertyMeta("inline_group_separation", "inlineGroupSeparation", "string", VersionMeta.Version101e, MoPropertyMeta.READ_ONLY, None, None, None, r"""^([\-]?)([123]?[1234]?)([0-9]{0,36})(([.])([0-9]{1,10}))?$""", ["not-applicable"], ["0-4294967295"]),
        "inline_group_size": MoPropertyMeta("inline_group_size", "inlineGroupSize", "ushort", VersionMeta.Version101e, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []),
        "inline_offset": MoPropertyMeta("inline_offset", "inlineOffset", "string", VersionMeta.Version101e, MoPropertyMeta.READ_ONLY, None, None, None, r"""^([\-]?)([123]?[1234]?)([0-9]{0,36})(([.])([0-9]{1,10}))?$""", ["not-applicable"], ["0-4294967295"]),
        "int_id": MoPropertyMeta("int_id", "intId", "string", VersionMeta.Version101e, MoPropertyMeta.INTERNAL, None, None, None, None, ["none"], ["0-4294967295"]),
        "location": MoPropertyMeta("location", "location", "string", VersionMeta.Version101e, MoPropertyMeta.READ_ONLY, None, None, None, None, ["back", "bottom", "front", "left", "right", "top", "unknown"], []),
        "name": MoPropertyMeta("name", "name", "string", VersionMeta.Version101e, MoPropertyMeta.READ_WRITE, 0x10, None, None, r"""[\-\.:_a-zA-Z0-9]{0,16}""", [], []),
        "number_of_onboard_disks": MoPropertyMeta("number_of_onboard_disks", "numberOfOnboardDisks", "ushort", VersionMeta.Version227b, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []),
        "number_of_slots": MoPropertyMeta("number_of_slots", "numberOfSlots", "ushort", VersionMeta.Version101e, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []),
        "onboard_disk_base_port_no": MoPropertyMeta("onboard_disk_base_port_no", "onboardDiskBasePortNo", "ushort", VersionMeta.Version227b, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []),
        "onboard_disk_first_index": MoPropertyMeta("onboard_disk_first_index", "onboardDiskFirstIndex", "ushort", VersionMeta.Version227b, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []),
        "orientation": MoPropertyMeta("orientation", "orientation", "string", VersionMeta.Version101e, MoPropertyMeta.READ_ONLY, None, None, None, None, ["horizontal", "unknown", "vertical"], []),
        "policy_level": MoPropertyMeta("policy_level", "policyLevel", "uint", VersionMeta.Version211a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []),
        "policy_owner": MoPropertyMeta("policy_owner", "policyOwner", "string", VersionMeta.Version211a, MoPropertyMeta.READ_WRITE, 0x20, None, None, None, ["local", "pending-policy", "policy"], []),
        "rn": MoPropertyMeta("rn", "rn", "string", VersionMeta.Version101e, MoPropertyMeta.READ_ONLY, 0x40, 0, 256, None, [], []),
        "sacl": MoPropertyMeta("sacl", "sacl", "string", VersionMeta.Version302c, MoPropertyMeta.READ_ONLY, None, None, None, r"""((none|del|mod|addchild|cascade),){0,4}(none|del|mod|addchild|cascade){0,1}""", [], []),
        "selector": MoPropertyMeta("selector", "selector", "string", VersionMeta.Version101e, MoPropertyMeta.NAMING, 0x80, None, None, None, ["blade", "com_port", "disk_slot", "drive_slot", "dvi_port", "ethernet_port", "fan", "gem", "iocard", "keyboard_port", "mouse_port", "par_port", "psu", "unknown", "usb_port", "vga_port"], []),
        "slots_per_line": MoPropertyMeta("slots_per_line", "slotsPerLine", "ushort", VersionMeta.Version101e, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []),
        "status": MoPropertyMeta("status", "status", "string", VersionMeta.Version101e, MoPropertyMeta.READ_WRITE, 0x100, None, None, r"""((removed|created|modified|deleted),){0,3}(removed|created|modified|deleted){0,1}""", [], []),
        "storage_bios_mode": MoPropertyMeta("storage_bios_mode", "storageBiosMode", "string", VersionMeta.Version224b, MoPropertyMeta.READ_ONLY, None, 0, 510, None, [], []),
        "sub_oem_id": MoPropertyMeta("sub_oem_id", "subOemId", "string", VersionMeta.Version224b, MoPropertyMeta.READ_ONLY, None, None, None, None, ["undefined"], ["0-65535"]),
        "transverse_group_separation": MoPropertyMeta("transverse_group_separation", "transverseGroupSeparation", "string", VersionMeta.Version101e, MoPropertyMeta.READ_ONLY, None, None, None, r"""^([\-]?)([123]?[1234]?)([0-9]{0,36})(([.])([0-9]{1,10}))?$""", ["not-applicable"], ["0-4294967295"]),
        "transverse_group_size": MoPropertyMeta("transverse_group_size", "transverseGroupSize", "ushort", VersionMeta.Version101e, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []),
        "transverse_offset": MoPropertyMeta("transverse_offset", "transverseOffset", "string", VersionMeta.Version101e, MoPropertyMeta.READ_ONLY, None, None, None, r"""^([\-]?)([123]?[1234]?)([0-9]{0,36})(([.])([0-9]{1,10}))?$""", ["not-applicable"], ["0-4294967295"]),
        "vertical_start_offset": MoPropertyMeta("vertical_start_offset", "verticalStartOffset", "string", VersionMeta.Version101e, MoPropertyMeta.READ_ONLY, None, None, None, r"""^([\-]?)([123]?[1234]?)([0-9]{0,36})(([.])([0-9]{1,10}))?$""", ["not-applicable"], ["0-4294967295"]),
        "width": MoPropertyMeta("width", "width", "string", VersionMeta.Version101e, MoPropertyMeta.READ_ONLY, None, None, None, r"""^([\-]?)([123]?[1234]?)([0-9]{0,36})(([.])([0-9]{1,10}))?$""", ["not-applicable"], ["0-4294967295"]),
    }

    prop_map = {
        "childAction": "child_action", 
        "descr": "descr", 
        "deviceSlotOffset": "device_slot_offset", 
        "dn": "dn", 
        "firstIndex": "first_index", 
        "height": "height", 
        "horizontalStartOffset": "horizontal_start_offset", 
        "inlineGroupSeparation": "inline_group_separation", 
        "inlineGroupSize": "inline_group_size", 
        "inlineOffset": "inline_offset", 
        "intId": "int_id", 
        "location": "location", 
        "name": "name", 
        "numberOfOnboardDisks": "number_of_onboard_disks", 
        "numberOfSlots": "number_of_slots", 
        "onboardDiskBasePortNo": "onboard_disk_base_port_no", 
        "onboardDiskFirstIndex": "onboard_disk_first_index", 
        "orientation": "orientation", 
        "policyLevel": "policy_level", 
        "policyOwner": "policy_owner", 
        "rn": "rn", 
        "sacl": "sacl", 
        "selector": "selector", 
        "slotsPerLine": "slots_per_line", 
        "status": "status", 
        "storageBiosMode": "storage_bios_mode", 
        "subOemId": "sub_oem_id", 
        "transverseGroupSeparation": "transverse_group_separation", 
        "transverseGroupSize": "transverse_group_size", 
        "transverseOffset": "transverse_offset", 
        "verticalStartOffset": "vertical_start_offset", 
        "width": "width", 
    }

    def __init__(self, parent_mo_or_dn, selector, **kwargs):
        self._dirty_mask = 0
        self.selector = selector
        self.child_action = None
        self.descr = None
        self.device_slot_offset = None
        self.first_index = None
        self.height = None
        self.horizontal_start_offset = None
        self.inline_group_separation = None
        self.inline_group_size = None
        self.inline_offset = None
        self.int_id = None
        self.location = None
        self.name = None
        self.number_of_onboard_disks = None
        self.number_of_slots = None
        self.onboard_disk_base_port_no = None
        self.onboard_disk_first_index = None
        self.orientation = None
        self.policy_level = None
        self.policy_owner = None
        self.sacl = None
        self.slots_per_line = None
        self.status = None
        self.storage_bios_mode = None
        self.sub_oem_id = None
        self.transverse_group_separation = None
        self.transverse_group_size = None
        self.transverse_offset = None
        self.vertical_start_offset = None
        self.width = None

        ManagedObject.__init__(self, "EquipmentSlotArray", parent_mo_or_dn, **kwargs)
